@@ -5,7 +5,7 @@ use warnings;
 
 use XSLoader;
 
-our $VERSION = '0.180300';
+our $VERSION = '0.210000';
 XSLoader::load('CommonMark', $VERSION);
 
 use constant {
@@ -42,11 +42,13 @@ use constant {
     EVENT_ENTER => 2,
     EVENT_EXIT  => 3,
 
-    OPT_DEFAULT    => 0,
-    OPT_SOURCEPOS  => 1,
-    OPT_HARDBREAKS => 2,
-    OPT_NORMALIZE  => 4,
-    OPT_SMART      => 8,
+    OPT_DEFAULT       =>  0,
+    OPT_SOURCEPOS     =>  1,
+    OPT_HARDBREAKS    =>  2,
+    OPT_NORMALIZE     =>  4,
+    OPT_SMART         =>  8,
+    OPT_VALIDATE_UTF8 => 16,
+    OPT_SAFE          => 32,
 };
 
 sub parse {
